package com.example.duplicate.controller;


import com.example.duplicate.controller.param.PageRequest;
import com.example.duplicate.controller.param.RcvPageRequest;
import com.example.duplicate.controller.vo.ExportBasic;
import com.example.duplicate.controller.vo.PageBasic;
import com.example.duplicate.service.RcvBasicService;
import com.example.utils.CommonResult;
import com.example.utils.ExcelExportHandler;
import com.example.utils.PageResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @ClassName RcvBasicController
 * @Description 示踪接口查询
 * @Author linjj
 * @Date 2025/6/20 12:21
 * @Version 1.0
 */
@RestController
@RequestMapping("/rcv/basic")
@Api(value = "示踪接口", tags = "示踪接口")
@Slf4j
public class RcvBasicController {

    @Autowired
    private RcvBasicService rcvBasicService;
    @Resource
    private ExcelExportHandler excelExportHandler;


    @ApiOperation("签收接口")
    @PostMapping("/Sign")
    public CommonResult<?> Sign(String patientId) {
        return rcvBasicService.Sign(patientId);
    }

    @ApiOperation("分页查询")
    @PostMapping("/pageAll")
    public CommonResult<PageResult<PageBasic>> pageAll(@RequestBody PageRequest pageRequest) {
        return rcvBasicService.pageAll(pageRequest);
    }

    @ApiOperation("修改签收状态")
    @PostMapping("/UpdateSign")
    public CommonResult<?> UpdateSign(@RequestParam @ApiParam(required = false, name = "patientId", value = "患者patientId")String patientId,
                                      @RequestParam @ApiParam(required = false, name = "revoveryState", value = "签收状态")String revoveryState) {
        return rcvBasicService.UpdateSign(patientId,revoveryState);
    }
    @ApiOperation("导出")
    @PostMapping("/export")
    public void pageExport(@RequestBody RcvPageRequest rcvPageRequest, HttpServletResponse response) {
        List<ExportBasic> pageBasics = rcvBasicService.pageExport(rcvPageRequest);
        if (!CollectionUtils.isEmpty(pageBasics)) {
            excelExportHandler.export(response, "病案回收管理列表", pageBasics, ExportBasic.class);
        }
    }

}
