package com.example.duplicate.service.impl;

import com.example.duplicate.controller.param.PageRequest;
import com.example.duplicate.controller.param.RcvPageRequest;
import com.example.duplicate.controller.param.SginBasicDto;
import com.example.duplicate.controller.vo.ExportBasic;
import com.example.duplicate.controller.vo.PageBasic;

import com.example.duplicate.infrastructure.dao.BasicMapper;
import com.example.duplicate.service.RcvBasicService;
import com.example.utils.CommonResult;
import com.example.utils.PageResult;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.sql.*;
import java.time.LocalDate;
import java.time.Period;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @ClassName RcvBasicServiceImpl
 * @Description
 * @Author linjj
 * @Date 2025/6/20 12:25
 * @Version 1.0
 */
@Service
@Slf4j
public class RcvBasicServiceImpl implements RcvBasicService {
    @Autowired
    private BasicMapper basicMapper;
    @Value("${lzUrl}")
    private String lzUrl;

    @Value("${lzUserName}")
    private String lzUserName;

    @Value("${lzPassword}")
    private String lzPassword;




    @Value("${jsUrl}")
    private String jsUrl;

    @Value("${jsUserName}")
    private String jsUserName;

    @Value("${jsPassword}")
    private String jsPassword;
    @Value("${powerUer}")
    private String powerUer;


    @Override
    public CommonResult<?> Sign(String patientId) {
        try {
        if (StringUtils.isBlank(patientId)){
            return CommonResult.failed("病案号不能为空！");
        }
        //查询是否已经存在数据，存在数据不在新增，直接返回已经签收
        List<String> idByPatientId = basicMapper.getIDByPatientId(patientId);
        if (!CollectionUtils.isEmpty(idByPatientId)) {
            return CommonResult.failed("病案ID【" + patientId + "】已签收过，不能重复签收");
        }
        String userName = getUserName();
        if (StringUtils.isBlank(userName)){
            return CommonResult.failed("获取用户姓名失败！");
        }
        SginBasicDto sginBasicDto=new SginBasicDto();
        // SQL Server连接信息
        String url = lzUrl;
        String username = lzUserName;
        String password = lzPassword;
        // SQL语句根据patientId查询患者基础信息
        String selectQuery = "SELECT * FROM dbo.V_sz_cybrxx WHERE 病案号='" + patientId + "'";
        log.info("查询语句为："+selectQuery);

            // 1. 加载SQL Server JDBC驱动
            Class.forName("com.microsoft.sqlserver.jdbc.SQLServerDriver");

            // 2. 建立数据库连接
            Connection connection = DriverManager.getConnection(url, username, password);

            // 3. 创建Statement对象用于执行SQL语句
            Statement statement = connection.createStatement();
            // 4. 执行查询操作
            ResultSet resultSet = statement.executeQuery(selectQuery);
            // 5. 处理查询结果并映射到RcvBasicVO对象
            while (resultSet.next()) {
                sginBasicDto.setPatientId(resultSet.getString("病案号"));
                sginBasicDto.setAdmissTimes(resultSet.getInt("住院次数"));
                sginBasicDto.setAdmissDate(resultSet.getDate("入院日期"));
                sginBasicDto.setDisDate(resultSet.getDate("出院日期"));
                sginBasicDto.setName(resultSet.getString("姓名"));
                String sex = resultSet.getString("性别");
                if (sex.equals("1")){
                    sginBasicDto.setSex("男");
                }
                if (sex.equals("2")){
                    sginBasicDto.setSex("女");
                }
                if (sex.equals("3")){
                    sginBasicDto.setSex("不详");
                }
                sginBasicDto.setBedNumber(resultSet.getString("床位号"));
                sginBasicDto.setAttendingName(resultSet.getString("责任人"));
                sginBasicDto.setDisDeptName(resultSet.getString("出院科室"));
                sginBasicDto.setRevoveryState("已签收");
                sginBasicDto.setRevoveryName(userName);
                sginBasicDto.setRevoveryTime(new Timestamp(System.currentTimeMillis()));
            }
            // 6. 关闭资源
            resultSet.close();
            statement.close();
            connection.close();
            //先插入数据到2.0中
            if (!getObjectCommonResult(sginBasicDto)){
                log.error("传送到病案数码系统失败");
                return CommonResult.failed("传送到病案数码系统失败,请联系管理员");
            }
            //插入数据
            if (!basicMapper.addBasic(sginBasicDto)){
                log.error("签收失败");
                return CommonResult.failed("签收失败");
            }
        } catch (Exception e) {
            log.error("签收失败： " + e,e.getMessage());
            return CommonResult.failed("签收失败： " + e.getMessage());
        }
        return CommonResult.success("签收完成");
    }
    /**
     * @description: 获取当前用户名
     * @author linjj
     * @date: 2025/6/27 11:12
     */
    private  String getUserName() {
        // 获取当前HttpServletRequest
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = requestAttributes.getRequest();
        // 从请求头中获取token
        String token = request.getHeader("token");
        try {
            // 接口URL
            String url = powerUer+"/front/sys/getUserInfoByToken";

            // 创建URL对象
            URL obj = new URL(url);
            // 打开连接
            HttpURLConnection con = (HttpURLConnection) obj.openConnection();

            // 设置请求方法为POST
            con.setRequestMethod("POST");

            // 设置请求头
            con.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");

            // 启用输出流
            con.setDoOutput(true);

            // 构建请求参数
            String urlParameters = "token=" + token;

            // 发送请求
            try (OutputStream os = con.getOutputStream()) {
                os.write(urlParameters.getBytes());
                os.flush();
            }

            // 获取响应码
            int responseCode = con.getResponseCode();
            System.out.println("响应码: " + responseCode);

            // 读取响应内容
            BufferedReader in = new BufferedReader(new InputStreamReader(con.getInputStream()));
            String inputLine;
            StringBuilder response = new StringBuilder();
            while ((inputLine = in.readLine()) != null) {
                    response.append(inputLine);
            }
            // 使用Jackson解析JSON响应内容
            ObjectMapper mapper = new ObjectMapper();
            JsonNode rootNode = mapper.readTree(response.toString());
            JsonNode dataNode = rootNode.get("data");
            String name = dataNode.get("userName").asText();
            // 断开连接
            con.disconnect();
            return name;
        } catch (Exception e) {
            log.error("获取用户失败： " + e,e.getMessage());
            return null;
        }
    }

    private Boolean getObjectCommonResult(SginBasicDto sginBasicDto) {
        // SQL Server连接信息
        String url = jsUrl;
        String username = jsUserName;
        String password = jsPassword;
        // 插入语句
        String insertQuery = "INSERT INTO lee_basic (patient_id, inpatient_no,admiss_times,name,admiss_date,dis_date) VALUES (replace(newid(), '-', ''),?, ?, ?, ?, ?);";
        log.info("执行的SQL语句为: " + insertQuery);
        try {
            // 1. 加载SQL Server JDBC驱动
            Class.forName("com.microsoft.sqlserver.jdbc.SQLServerDriver");

            // 2. 建立数据库连接
            Connection connection = DriverManager.getConnection(url, username, password);

            // 3. 创建PreparedStatement对象用于执行SQL语句
            PreparedStatement preparedStatement = connection.prepareStatement(insertQuery);

            // 4. 设置参数
            preparedStatement.setString(1, sginBasicDto.getPatientId());
            preparedStatement.setInt(2, sginBasicDto.getAdmissTimes());
            preparedStatement.setString(3, sginBasicDto.getName());
            preparedStatement.setDate(4, new java.sql.Date(sginBasicDto.getAdmissDate().getTime()));
            preparedStatement.setDate(5, new java.sql.Date(sginBasicDto.getDisDate().getTime()));
            // 5. 执行插入操作
            preparedStatement.executeUpdate();

            // 6. 关闭资源
            preparedStatement.close();
            connection.close();
        } catch (Exception e) {
            log.error("传送到病案数码系统失败： " + e,e.getMessage());
            return false;
        }
        log.info("插入2.0中成功");
        return true;
    }

    @Override
    public CommonResult<PageResult<PageBasic>>pageAll(PageRequest pageRequest) {
        PageResult<PageBasic> pageResult = null;
        try {
            // 设置分页参数
            PageHelper.startPage(pageRequest.getPage(), pageRequest.getSize());
            List<PageBasic> pageAll = basicMapper.getPageAll(pageRequest);
            pageResult = new PageResult<>(pageAll);
        } catch (Exception e) {
            log.error("系统异常： " + e.getMessage());
           return CommonResult.failed("系统异常");
        }
        return CommonResult.success(pageResult);
    }

    @Override
    public CommonResult<?> UpdateSign(String patientId,String revoveryState) {
        String userName = getUserName();
        if (revoveryState.equals("已签收")){
            basicMapper.UpdateState(patientId,"未签收",userName);
            return CommonResult.success("取消签收成功");
        }
        if (revoveryState.equals("未签收")){
            basicMapper.UpdateState(patientId,"已签收",userName);
            return CommonResult.success("签收成功");
        }
        return null;
    }

    @Override
    public List<ExportBasic> pageExport(RcvPageRequest rcvPageRequest) {
        List<ExportBasic> pageBasics = basicMapper.pageExport(rcvPageRequest);
        return pageBasics;
    }
}
