package com.example.duplicate.service.impl;

import com.example.duplicate.controller.param.CallRequest;
import com.example.duplicate.controller.vo.CallBasic;
import com.example.duplicate.controller.vo.CallExpoetBasic;
import com.example.duplicate.controller.vo.DeptCodeAndName;
import com.example.duplicate.infrastructure.dao.BasicMapper;
import com.example.duplicate.service.RcvCallService;
import com.example.utils.CommonResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.sql.*;
import java.util.*;
import java.util.Date;
import java.util.stream.Collectors;

/**
 * @ClassName RcvCallServiceImpl
 * @Description 催缴业务层
 * @Author linjj
 * @Date 2025/6/26 16:25
 * @Version 1.0
 */
@Service
@Slf4j
public class RcvCallServiceImpl  implements RcvCallService {

    @Value("${lzUrl}")
    private String lzUrl;

    @Value("${lzUserName}")
    private String lzUserName;

    @Value("${lzPassword}")
    private String lzPassword;
    @Autowired
    private BasicMapper basicMapper;

    @Override
    public List<DeptCodeAndName> deptName() {
//        // SQL Server连接信息
//        String url = lzUrl;
//        String username = lzUserName;
//        String password = lzPassword;
//        try {
//            List<String> deptNames=new ArrayList<>();
//            // SQL语句根据patientId查询患者基础信息
//            String selectQuery = "SELECT 出院科室 FROM dbo.V_sz_cybrxx where 出院科室 is not null AND 出院科室 !=''  GROUP BY 出院科室";
//            // 1. 加载SQL Server JDBC驱动
//            Class.forName("com.microsoft.sqlserver.jdbc.SQLServerDriver");
//
//            // 2. 建立数据库连接
//            Connection connection = DriverManager.getConnection(url, username, password);
//
//            // 3. 创建Statement对象用于执行SQL语句
//            Statement statement = connection.createStatement();
//            // 4. 执行查询操作
//            ResultSet resultSet = statement.executeQuery(selectQuery);
//            // 5. 遍历查询结果并添加到deptNames列表中
//            while (resultSet.next()) {
//                String deptName = resultSet.getString("出院科室");
//                deptNames.add(deptName);
//            }
//            // 6. 关闭数据库资源
//            resultSet.close();
//            statement.close();
//            connection.close();
//            return deptNames;
//        } catch (Exception e) {
//            log.error("查询科室失败： " + e, e.getMessage());
//            return null;
//        }
        List<DeptCodeAndName> deptCodeAndName = basicMapper.getDeptCodeAndName();
        return deptCodeAndName;
    }

    @Override
    public CommonResult<List<Map<String, Object>>> callAll(CallRequest callRequest) {
        // SQL Server连接信息
        String url = lzUrl;
        String username = lzUserName;
        String password = lzPassword;
        // 构建SQL查询语句
        StringBuilder selectQuery = new StringBuilder();
        selectQuery.append("SELECT * ");
        selectQuery.append("FROM dbo.V_sz_cybrxx ");
        selectQuery.append("WHERE 1=1 ");
        List<Object> parameters = new ArrayList<>();
        List<Map<String, Object>> result = new ArrayList<>();
        // 添加出院科室条件
        if (callRequest.getDisDeptName() != null && !callRequest.getDisDeptName().isEmpty()) {
            String[] deptNames = callRequest.getDisDeptName().split(",");
            String inClause = String.join(",", Collections.nCopies(deptNames.length, "?"));
            selectQuery.append(" AND 出院科室 IN (" + inClause + ")");
            parameters.addAll(Arrays.asList(deptNames));
        }


        if (callRequest.getName() != null && !callRequest.getName().isEmpty()) {
            selectQuery.append(" AND 姓名 = ?");
            parameters.add(callRequest.getEndTime());
        }


        // 添加时间范围条件
        if (callRequest.getStartTime() != null) {
            selectQuery.append(" AND 出院日期 >= ?");
            parameters.add(callRequest.getStartTime());
        }

        if (callRequest.getEndTime() != null) {
            selectQuery.append(" AND 出院日期 <= ?");
            parameters.add(callRequest.getEndTime());
        }

        // 添加出院天数条件
        if (callRequest.getOutNum() != null && !callRequest.getOutNum().isEmpty()) {
            selectQuery.append(" AND DATEDIFF(day, 出院日期, GETDATE()) >= ?");
            parameters.add(callRequest.getOutNum());
        }
        try (Connection connection = DriverManager.getConnection(url, username, password);
             PreparedStatement preparedStatement = connection.prepareStatement(selectQuery.toString())) {
            // 设置查询参数
            for (int i = 0; i < parameters.size(); i++) {
                preparedStatement.setObject(i + 1, parameters.get(i));
            }
            ResultSet resultSet = preparedStatement.executeQuery();
            // 处理查询结果
            List<CallBasic> callBasicList = new ArrayList<>();
            while (resultSet.next()) {
                CallBasic callBasic = new CallBasic();
                callBasic.setDisDeptName(resultSet.getString("出院科室"));
                callBasic.setPatientId(resultSet.getString("病案号"));
                callBasic.setAdmissTimes(resultSet.getInt("住院次数"));
                callBasic.setDisDate(resultSet.getDate("出院日期"));
                callBasic.setName(resultSet.getString("姓名"));
                String sex = resultSet.getString("性别");
                if (sex.equals("1")){
                    callBasic.setSex("男");
                }
                if (sex.equals("2")){
                    callBasic.setSex("女");
                }
                if (sex.equals("3")){
                    callBasic.setSex("不详");
                }
                callBasic.setBedNumber(resultSet.getString("床位号"));
                callBasic.setOutNum(resultSet.getInt("已出院天数"));
                callBasic.setAttendingName(resultSet.getString("责任人"));
                callBasicList.add(callBasic);
            }
            //查询已经签收数据
            List<String> basciByState = basicMapper.getBasciByState(callRequest);
            //将 basciByState 转换为一个 Set，因为 Set 的 contains 方法性能更高
            Set<String> basciByStateSet = new HashSet<>(basciByState);
            //使用已经签收数据，跟查询到的联众数据进行匹配，有相同的病案号则去掉改记录
            callBasicList.removeIf(callBasic -> basciByStateSet.contains(callBasic.getPatientId()));
            // 按科室分组并构建新的返回结构
            Map<String, List<CallBasic>> groupedByDept = callBasicList.stream()
                    .collect(Collectors.groupingBy(CallBasic::getDisDeptName));

            for (Map.Entry<String, List<CallBasic>> entry : groupedByDept.entrySet()) {
                Map<String, Object> deptEntry = new LinkedHashMap<>();
                deptEntry.put("disDeptNameTree", "出院科室:"+entry.getKey()+"("+entry.getValue().size()+"份)");
                deptEntry.put("patients", entry.getValue());
                result.add(deptEntry);
            }
            return CommonResult.success(result);
        } catch (Exception e) {
            log.error("查询失败: {}", e.getMessage());
            return CommonResult.failed("查询失败"+e.getMessage());
        }
    }

    @Override
    public List<CallExpoetBasic> exportCall(CallRequest callRequest) {
        // SQL Server连接信息
        String url = lzUrl;
        String username = lzUserName;
        String password = lzPassword;
        // 构建SQL查询语句
        StringBuilder selectQuery = new StringBuilder();
        selectQuery.append("SELECT * ");
        selectQuery.append("FROM dbo.V_sz_cybrxx ");
        selectQuery.append("WHERE 1=1 ");
        List<Object> parameters = new ArrayList<>();
        List<Map<String, Object>> result = new ArrayList<>();
        // 添加出院科室条件（假设 CallPageRequest 中有 deptName 字段）
        if (callRequest.getDisDeptName() != null && !callRequest.getDisDeptName().isEmpty()) {
            String[] deptNames = callRequest.getDisDeptName().split(",");
            String inClause = String.join(",", Collections.nCopies(deptNames.length, "?"));
            selectQuery.append(" AND 出院科室 IN (" + inClause + ")");
            parameters.addAll(Arrays.asList(deptNames));
        }
        // 添加时间范围条件
        if (callRequest.getStartTime() != null) {
            selectQuery.append(" AND 出院日期 >= ?");
            parameters.add(callRequest.getStartTime());
        }
        if (callRequest.getEndTime() != null) {
            selectQuery.append(" AND 出院日期 <= ?");
            parameters.add(callRequest.getEndTime());
        }
        // 添加出院天数条件
        if (callRequest.getOutNum() != null && !callRequest.getOutNum().isEmpty()) {
            selectQuery.append(" AND DATEDIFF(day, 出院日期, GETDATE()) >= ?");
            parameters.add(callRequest.getOutNum());
        }
        try (Connection connection = DriverManager.getConnection(url, username, password);
             PreparedStatement preparedStatement = connection.prepareStatement(selectQuery.toString())) {
            // 设置查询参数
            for (int i = 0; i < parameters.size(); i++) {
                preparedStatement.setObject(i + 1, parameters.get(i));
            }
            ResultSet resultSet = preparedStatement.executeQuery();
            // 处理查询结果
            List<CallExpoetBasic> callBasicList = new ArrayList<>();
            while (resultSet.next()) {
                CallExpoetBasic callBasic = new CallExpoetBasic();
                callBasic.setDisDeptName(resultSet.getString("出院科室"));
                callBasic.setPatientId(resultSet.getString("病案号"));
                callBasic.setAdmissTimes(resultSet.getInt("住院次数"));
                callBasic.setDisDate(resultSet.getDate("出院日期"));
                callBasic.setName(resultSet.getString("姓名"));
                String sex = resultSet.getString("性别");
                if (sex.equals("1")){
                    callBasic.setSex("男");
                }
                if (sex.equals("2")){
                    callBasic.setSex("女");
                }
                if (sex.equals("3")){
                    callBasic.setSex("不详");
                }
                callBasic.setBedNumber(resultSet.getString("床位号"));
                callBasic.setOutNum(resultSet.getInt("已出院天数"));
                callBasic.setAttendingName(resultSet.getString("责任人"));
                callBasicList.add(callBasic);
            }
            //查询已经签收数据
            List<String> basciByState = basicMapper.getBasciByState(callRequest);
            //将 basciByState 转换为一个 Set，因为 Set 的 contains 方法性能更高
            Set<String> basciByStateSet = new HashSet<>(basciByState);
            //使用已经签收数据，跟查询到的联众数据进行匹配，有相同的病案号则去掉改记录
            callBasicList.removeIf(callBasic -> basciByStateSet.contains(callBasic.getPatientId()));
            return callBasicList;
        } catch (Exception e) {
            log.error("查询失败: {}", e.getMessage());
            return null;
        }
    }
}
