package com.example.utils;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageSerializable;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

/**
 * @ClassName PageResult
 * @Description
 * @Author linjj
 * @Date 2025/6/20 12:37
 * @Version 1.0
 */
@ApiModel(
        value = "PageResult对象",
        description = "分页管理"
)
public class PageResult<T> extends PageSerializable<T> {

    @ApiModelProperty("页码")
    private int pageNum;
    @ApiModelProperty("每页的条数")
    private int pageSize;
    @ApiModelProperty("总页数")
    private int pageCount;

    public PageResult() {
    }

    public PageResult(List<T> list) {
        super(list);
        if (list instanceof Page) {
            Page page = (Page)list;
            this.pageNum = page.getPageNum();
            this.pageSize = page.getPageSize();
            this.pageCount = page.getPages();
        } else {
            this.pageNum = 1;
            this.pageSize = list.size();
            this.pageCount = 1;
        }

    }

    public PageResult(List<T> list, long total, int pageNum, int pageSize) {
        this.setTotal(total);
        this.pageNum = pageNum;
        this.pageSize = pageSize;
        this.pageCount = (int)((total + (long)pageSize - 1L) / (long)pageSize);
        this.setList(list);
    }

    public int getPageNum() {
        return this.pageNum;
    }

    public int getPageSize() {
        return this.pageSize;
    }

    public int getPageCount() {
        return this.pageCount;
    }

    public void setPageNum(int pageNum) {
        this.pageNum = pageNum;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }

    public void setPageCount(int pageCount) {
        this.pageCount = pageCount;
    }
}
